@@ -5,6 +5,7 @@
 # Copyright (C) 2022 The lesscode Team
 
 import aioredis
+import redis
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
 
@@ -26,3 +27,9 @@ class RedisPool(BaseConnectionPool):
             return pool
         else:
             raise NotImplementedError
+
+    def sync_create_pool(self):
+        pool = redis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", port=self.conn_info.port,
+                                             password=self.conn_info.password,
+                                             db=self.conn_info.db_name, encoding="utf-8", decode_responses=True)
+        return pool
