@@ -1,7 +1,7 @@
 import logging
 from datetime import datetime, timedelta
 
-from lesscode.utils.aes import AES
+from lesscode.utils.encryption_algorithm import AES
 from tornado.options import options
 
 
