@@ -7,7 +7,7 @@ import py_eureka_client.eureka_client as eureka_client
 
 async def post(path, data=None,
                base_url=tornado.options.options.data_server,
-               result_type="json", pack=True, **kwargs):
+               result_type="json", pack=False, **kwargs):
     async with aiohttp.ClientSession() as session:
         async with session.post(base_url + path, json=data, **kwargs) as resp:
             if result_type == "json":
@@ -17,11 +17,11 @@ async def post(path, data=None,
             elif result_type == "text":
                 result = await resp.text()
             else:
-                result = await resp.content
+                result = await resp.content.read()
             return result
 
 
-async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=True, **kwargs):
+async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False, **kwargs):
     async with aiohttp.ClientSession() as session:
         async with session.get(base_url + path, params=params, **kwargs) as resp:
             if result_type == "json":
@@ -31,11 +31,11 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
             elif result_type == "text":
                 result = await resp.text()
             else:
-                result = await resp.content
+                result = await resp.content.read()
             return result
 
 
-def sync_get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=True, **kwargs):
+def sync_get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False, **kwargs):
     res = requests.get(base_url + path, params=params, **kwargs)
     if result_type == "json":
         res = res.json()
@@ -50,7 +50,7 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
 
 def sync_post(path, data=None,
               base_url=tornado.options.options.data_server,
-              result_type="json", pack=True, **kwargs):
+              result_type="json", pack=False, **kwargs):
     res = requests.post(base_url + path, json=data, **kwargs)
     if result_type == "json":
         res = res.json()
@@ -63,7 +63,7 @@ def sync_post(path, data=None,
     return res
 
 
-def eureka_request(path="", return_type="json", method="GET", data=None, app_name="DATA_SERVICE", pack=True, **kwargs):
+def eureka_request(path="", return_type="json", method="GET", data=None, app_name="DATA_SERVICE", pack=False, **kwargs):
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
             "Content-Type": "application/json"
@@ -75,25 +75,29 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
     return res
 
 
-def eureka_get(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=True, **kwargs):
+def eureka_get(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=False, **kwargs):
+    base_url = kwargs.pop("base_url")
     if tornado.options.options.running_env != "local":
+
         res = eureka_request(path=path, return_type=return_type, method="GET", data=data, app_name=app_name, pack=pack,
                              **kwargs)
     else:
-        res = sync_get(path=path, params=data, base_url=kwargs.get("base_url") if kwargs.get(
-            "base_url") else tornado.options.options.data_server,
+        res = sync_get(path=path, params=data, base_url=base_url if base_url else tornado.options.options.data_server,
                        result_type=return_type,
                        pack=pack, **kwargs)
     return res
 
 
-def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=True, **kwargs):
+def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=False, **kwargs):
+    base_url = kwargs.pop("base_url")
     if tornado.options.options.running_env != "local":
+
         res = eureka_request(path=path, return_type=return_type, method="POST", data=json.dumps(data),
                              app_name=app_name,
                              pack=pack, **kwargs)
     else:
-        res = sync_post(path=path, data=data, base_url=kwargs.get("base_url") if kwargs.get(
-            "base_url") else tornado.options.options.data_server, result_type=return_type,
+
+        res = sync_post(path=path, data=data, base_url=base_url if base_url else tornado.options.options.data_server,
+                        result_type=return_type,
                         pack=pack, **kwargs)
     return res
