@@ -97,10 +97,11 @@ def Handler(url: str):
                         print(f"add url={full_url} to rms fail")
         cls.__route_name__ = url
         return cls
+
     return wrapper
 
 
-def GetMapping(url: str, client_name: str = None, title: str = None, en_name: str = None, access: str = 1):
+def GetMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1):
     """
     用于类名、处理方法、url 的元祖集合注册处理，暂时GetMapping与PostMapping实现保持一致，预留入口为后期扩展提供支持。
     :param client_name:
@@ -113,15 +114,19 @@ def GetMapping(url: str, client_name: str = None, title: str = None, en_name: st
 
     def wrapper(func):
         # 组合  类名、处理方法、url 的元祖 （url仅代表方法上Mapping装饰器的参数）
+        path = url
+        if not path:
+            path = "/{}".format(func.__name__)
         RouterMapping.instance().dynamicMethods.append(
-            (func.__qualname__.replace('.' + func.__name__, ''), func, url, client_name, title, en_name, access))
-        func.__route_name__ = url
+            (func.__qualname__.replace('.' + func.__name__, ''), func, path, client_name, title, en_name, access))
+        func.__route_name__ = path
         func.__http_method__ = "get"
         return func
+
     return wrapper
 
 
-def PostMapping(url: str, client_name: str = None, title: str = None, en_name: str = None, access: str = 1):
+def PostMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1):
     """
     用于类名、处理方法、url 的元祖集合注册处理，暂时GetMapping与PostMapping实现保持一致，预留入口为后期扩展提供支持。
     :param client_name:
@@ -134,9 +139,13 @@ def PostMapping(url: str, client_name: str = None, title: str = None, en_name: s
 
     def wrapper(func):
         # 组合  类名、处理方法、url 的元祖 （url仅代表方法上Mapping装饰器的参数）
+        path = url
+        if not path:
+            path = "/{}".format(func.__name__)
         RouterMapping.instance().dynamicMethods.append(
-            (func.__qualname__.replace('.' + func.__name__, ''), func, url, client_name, title, en_name, access))
-        func.__route_name__ = url
+            (func.__qualname__.replace('.' + func.__name__, ''), func, path, client_name, title, en_name, access))
+        func.__route_name__ = path
         func.__http_method__ = "post"
         return func
+
     return wrapper
